==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/OthersCategoryContext.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var OthersCategoryContext = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OthersCategoryContext, _super);
    function OthersCategoryContext() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._items = null;
        return _this;
    }
    Object.defineProperty(OthersCategoryContext.prototype, "items", {
        get: function () {
            return this._items;
        },
        set: function (a) {
            this._items = a;
        },
        enumerable: false,
        configurable: true
    });
    OthersCategoryContext.b = function (a, b) {
        var c = null;
        if (b != null && b.c9.j.ae != null) {
            c = b.c9.j.ae.getExternal(a, null, null);
        }
        return c;
    };
    OthersCategoryContext.$t = markType(OthersCategoryContext, 'OthersCategoryContext');
    return OthersCategoryContext;
}(Base));
export { OthersCategoryContext };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/OthersCategoryContext.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var OthersCategoryContext = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OthersCategoryContext, _super);
    function OthersCategoryContext() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._items = null;
        return _this;
    }
    Object.defineProperty(OthersCategoryContext.prototype, "items", {
        get: function () {
            return this._items;
        },
        set: function (a) {
            this._items = a;
        },
        enumerable: false,
        configurable: true
    });
    OthersCategoryContext.b = function (a, b) {
        var c = null;
        if (b != null && b.dc.j.ae != null) {
            c = b.dc.j.ae.getExternal(a, null, null);
        }
        return c;
    };
    OthersCategoryContext.$t = markType(OthersCategoryContext, 'OthersCategoryContext');
    return OthersCategoryContext;
}(Base));
export { OthersCategoryContext };
